"""Saved views snapshot."""

DATA_SAVED_VIEWS = {
    "count": 5,
    "next": None,
    "previous": None,
    "all": [1, 2, 3, 4, 5],
    "results": [
        {
            "id": 1,
            "name": "New Items",
            "show_on_dashboard": False,
            "show_in_sidebar": False,
            "sort_field": None,
            "sort_reverse": False,
            "filter_rules": [{"rule_type": 6, "value": "1"}],
            "owner": 1,
            "user_can_change": True,
        },
        {
            "id": 2,
            "name": "New Items Alpha",
            "show_on_dashboard": True,
            "show_in_sidebar": False,
            "sort_field": "title",
            "sort_reverse": False,
            "filter_rules": [
                {"rule_type": 6, "value": "1"},
                {"rule_type": 33, "value": "7"},
            ],
            "owner": 1,
            "user_can_change": True,
        },
        {
            "id": 3,
            "name": "New Items Omega",
            "show_on_dashboard": True,
            "show_in_sidebar": False,
            "sort_field": None,
            "sort_reverse": False,
            "filter_rules": [
                {"rule_type": 6, "value": "1"},
                {"rule_type": 35, "value": "7"},
            ],
            "owner": 1,
            "user_can_change": True,
        },
        {
            "id": 4,
            "name": "Tax",
            "show_on_dashboard": False,
            "show_in_sidebar": True,
            "sort_field": "created",
            "sort_reverse": True,
            "filter_rules": [{"rule_type": 6, "value": "3"}],
            "owner": 1,
            "user_can_change": True,
        },
        {
            "id": 5,
            "name": "Todo",
            "show_on_dashboard": False,
            "show_in_sidebar": True,
            "sort_field": "created",
            "sort_reverse": True,
            "filter_rules": [{"rule_type": 6, "value": "4"}],
            "owner": 1,
            "user_can_change": True,
        },
    ],
}
